netapp_ontap.models.firmware_dqp_record_count API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.firmware_dqp_record_count`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FirmwareDqpRecordCountSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FirmwareDqpRecordCount object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `alias GET`

    Alias record count

    Example: 200

  `device GET`

    Device record count

    Example: 29

  `drive GET`

    Drive record count

    Example: 680

  `system GET`

    System record count

    Example: 3